"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_server_express_1 = require("apollo-server-express");
const logger_1 = require("../logger");
const loaders_1 = require("../loaders");
const database_connector_1 = __importDefault(require("../connectors/database-connector"));
class App {
    constructor(config) {
        this.config = config;
        this.gqlLoader = new loaders_1.GqlLoader();
    }
    async buildServer() {
        try {
            logger_1.logger.log('Connecting to database', 'Database');
            const connection = await database_connector_1.default.createConnection(this.config.db);
            logger_1.logger.log('Successfully connected', 'Database');
            if (!this.config.db.synchronize) {
                await connection.runMigrations();
            }
            logger_1.logger.log('Migrations ran', 'Database');
            return new apollo_server_express_1.ApolloServer({
                playground: {
                    endpoint: this.config.playgroundUrl,
                },
                introspection: true,
                typeDefs: await this.gqlLoader.getTypeDefs(),
                resolvers: await this.gqlLoader.getResolvers(),
                uploads: false,
                context: () => ({
                    db: connection,
                }),
            });
        }
        catch (e) {
            throw new Error(`Server failed to start, error: ${e}`);
        }
    }
}
exports.default = App;
//# sourceMappingURL=app.js.map