"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bootstrap = void 0;
const express_1 = __importDefault(require("express"));
const logger_1 = require("../logger");
const app_1 = __importDefault(require("./app"));
const bootstrap = async (config, initContextStorage) => {
    try {
        logger_1.logger.log('Start bootstrapping the application', 'Bootstrap');
        const csApp = new app_1.default(config);
        const server = await csApp.buildServer();
        const { port } = config;
        const expressApp = express_1.default();
        if (initContextStorage) {
            initContextStorage(expressApp);
        }
        expressApp.use('/health', (req, res) => res.json());
        server.applyMiddleware({ app: expressApp });
        expressApp.listen({ port }, () => {
            logger_1.logger.log(`Graphql is available on: http://localhost:${port}/graphql`, 'Bootstrap');
        });
    }
    catch (error) {
        logger_1.logger.error(error, error.stack, 'Bootstrap', config);
        process.exit(0);
    }
};
exports.bootstrap = bootstrap;
//# sourceMappingURL=bootstrap.js.map